@@ -378,6 +378,30 @@ def copy_singlefile_from_archive(scrfile_path, dstfile_path):
 #################################################################################################
 #################################################################################################
 
+def read_raster_info(raster_filepath):
+    ds = gdal.Open(str(raster_filepath))
+
+    gt = ds.GetGeoTransform()
+    ulx_raster = gt[0]
+    uly_raster = gt[3]
+    lrx_raster = gt[0] + gt[1] * ds.RasterXSize + gt[2] * ds.RasterYSize
+    lry_raster = gt[3] + gt[4] * ds.RasterXSize + gt[5] * ds.RasterYSize
+    imagery_extent_box = box(lrx_raster, uly_raster, ulx_raster, lry_raster)
+    ds = None
+
+    xmin = gt[0]
+    ymax = gt[3]
+    pixel_width = gt[1]
+    yres = gt[5]
+
+    projection = ds.GetProjection()
+    datatype = ds.GetRasterBand(1).DataType
+    n_bands = ds.RasterCount
+    epsg = ds.GetSpatialRef().GetAuthorityCode(None)
+
+    return (xmin, ymax, ds.RasterXSize, ds.RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
+
+
 def reproject_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
 
     cmd = ["gdalwarp",
